@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import asyncio
 import datetime
+from collections.abc import AsyncIterator
 from contextlib import asynccontextmanager
 from dataclasses import dataclass, field, replace
 from decimal import Decimal
-from typing import Any, AsyncIterator, Dict, List, Optional
+from typing import Any
 
 import aiohttp
 import aiohttp.web
@@ -44,22 +47,22 @@ def _parse_bool(value: str) -> bool:
 
 @dataclass()
 class AdminServer:
-    address: Optional[ApiAddress] = None
+    address: ApiAddress | None = None
 
-    users: List[User] = field(default_factory=list)
-    clusters: List[Cluster] = field(default_factory=list)
-    orgs: List[Org] = field(default_factory=list)
-    cluster_users: List[ClusterUser] = field(default_factory=list)
-    org_clusters: List[OrgCluster] = field(default_factory=list)
-    org_users: List[OrgUser] = field(default_factory=list)
-    debts: List[Debt] = field(default_factory=list)
+    users: list[User] = field(default_factory=list)
+    clusters: list[Cluster] = field(default_factory=list)
+    orgs: list[Org] = field(default_factory=list)
+    cluster_users: list[ClusterUser] = field(default_factory=list)
+    org_clusters: list[OrgCluster] = field(default_factory=list)
+    org_users: list[OrgUser] = field(default_factory=list)
+    debts: list[Debt] = field(default_factory=list)
 
     @property
     def url(self) -> URL:
         assert self.address
         return URL(f"http://{self.address.host}:{self.address.port}/api/v1/")
 
-    def _serialize_user(self, user: User) -> Dict[str, Any]:
+    def _serialize_user(self, user: User) -> dict[str, Any]:
         return {
             "name": user.name,
             "email": user.email,
@@ -68,7 +71,7 @@ class AdminServer:
             "created_at": user.created_at.isoformat() if user.created_at else None,
         }
 
-    def _serialize_user_cluster(self, user: ClusterUser) -> Dict[str, Any]:
+    def _serialize_user_cluster(self, user: ClusterUser) -> dict[str, Any]:
         res = self._serialize_cluster_user(user, False)
         res.pop("user_name")
         res["cluster_name"] = user.cluster_name
@@ -110,7 +113,7 @@ class AdminServer:
         resp = [self._serialize_user(user) for user in self.users]
         return aiohttp.web.json_response(resp)
 
-    def _serialize_org(self, org: Org) -> Dict[str, Any]:
+    def _serialize_org(self, org: Org) -> dict[str, Any]:
         return {
             "name": org.name,
         }
@@ -150,21 +153,71 @@ class AdminServer:
         resp = [self._serialize_org(org) for org in self.orgs]
         return aiohttp.web.json_response(resp)
 
-    def _serialize_cluster(self, cluster: Cluster) -> Dict[str, Any]:
-        return {
+    def _serialize_cluster(self, cluster: Cluster) -> dict[str, Any]:
+        resp: dict[str, Any] = {
             "name": cluster.name,
+            "default_quota": {},
         }
+        if cluster.default_credits:
+            resp["default_credits"] = str(cluster.default_credits)
+        if cluster.default_quota.total_running_jobs:
+            resp["default_quota"][
+                "total_running_jobs"
+            ] = cluster.default_quota.total_running_jobs
+        return resp
+
+    def _int_or_none(self, value: str | None) -> int | None:
+        if value:
+            return int(value)
+        return None
 
     async def handle_cluster_post(
         self, request: aiohttp.web.Request
     ) -> aiohttp.web.Response:
         payload = await request.json()
+        default_credits_raw = payload.get("default_credits")
+        default_quota_raw = payload.get("default_quota", {})
         new_cluster = Cluster(
             name=payload["name"],
+            default_credits=Decimal(default_credits_raw)
+            if default_credits_raw
+            else None,
+            default_quota=Quota(
+                total_running_jobs=self._int_or_none(
+                    default_quota_raw.get("total_running_jobs")
+                )
+            ),
         )
         self.clusters.append(new_cluster)
         return aiohttp.web.json_response(self._serialize_cluster(new_cluster))
 
+    async def handle_cluster_put(
+        self, request: aiohttp.web.Request
+    ) -> aiohttp.web.Response:
+        cluster_name = request.match_info["cname"]
+        payload = await request.json()
+
+        assert cluster_name == payload["name"]
+
+        default_credits_raw = payload.get("default_credits")
+        default_quota_raw = payload.get("default_quota", {})
+        changed_cluster = Cluster(
+            name=payload["name"],
+            default_credits=Decimal(default_credits_raw)
+            if default_credits_raw
+            else None,
+            default_quota=Quota(
+                total_running_jobs=self._int_or_none(
+                    default_quota_raw.get("total_running_jobs")
+                )
+            ),
+        )
+        self.clusters = [
+            cluster for cluster in self.clusters if cluster.name != changed_cluster.name
+        ]
+        self.clusters.append(changed_cluster)
+        return aiohttp.web.json_response(self._serialize_cluster(changed_cluster))
+
     async def handle_cluster_get(
         self, request: aiohttp.web.Request
     ) -> aiohttp.web.Response:
@@ -192,8 +245,8 @@ class AdminServer:
 
     def _serialize_cluster_user(
         self, cluster_user: ClusterUser, with_info: bool
-    ) -> Dict[str, Any]:
-        res: Dict[str, Any] = {
+    ) -> dict[str, Any]:
+        res: dict[str, Any] = {
             "user_name": cluster_user.user_name,
             "role": cluster_user.role.value,
             "org_name": cluster_user.org_name,
@@ -454,8 +507,8 @@ class AdminServer:
         ]
         return aiohttp.web.json_response(resp)
 
-    def _serialize_org_user(self, org_user: OrgUser, with_info: bool) -> Dict[str, Any]:
-        res: Dict[str, Any] = {
+    def _serialize_org_user(self, org_user: OrgUser, with_info: bool) -> dict[str, Any]:
+        res: dict[str, Any] = {
             "user_name": org_user.user_name,
             "role": org_user.role.value,
             "org_name": org_user.org_name,
@@ -548,18 +601,25 @@ class AdminServer:
         ]
         return aiohttp.web.json_response(resp)
 
-    def _serialize_org_cluster(self, org_cluster: OrgCluster) -> Dict[str, Any]:
-        res: Dict[str, Any] = {
+    def _serialize_org_cluster(self, org_cluster: OrgCluster) -> dict[str, Any]:
+        res: dict[str, Any] = {
             "org_name": org_cluster.org_name,
             "quota": {},
             "balance": {
                 "spent_credits": str(org_cluster.balance.spent_credits),
             },
+            "default_quota": {},
         }
         if org_cluster.quota.total_running_jobs is not None:
             res["quota"]["total_running_jobs"] = org_cluster.quota.total_running_jobs
         if org_cluster.balance.credits is not None:
             res["balance"]["credits"] = str(org_cluster.balance.credits)
+        if org_cluster.default_credits:
+            res["default_credits"] = str(org_cluster.default_credits)
+        if org_cluster.default_quota.total_running_jobs:
+            res["default_quota"][
+                "total_running_jobs"
+            ] = org_cluster.default_quota.total_running_jobs
         return res
 
     async def handle_org_cluster_post(
@@ -568,6 +628,7 @@ class AdminServer:
         cluster_name = request.match_info["cname"]
         payload = await request.json()
         credits_raw = payload.get("balance", {}).get("credits")
+        default_credits_raw = payload.get("default_credits")
         spend_credits_raw = payload.get("balance", {}).get("spend_credits_raw")
         new_org_cluster = OrgCluster(
             cluster_name=cluster_name,
@@ -581,6 +642,14 @@ class AdminServer:
                 if spend_credits_raw
                 else Decimal(0),
             ),
+            default_quota=Quota(
+                total_running_jobs=payload.get("default_quota", {}).get(
+                    "total_running_jobs"
+                )
+            ),
+            default_credits=Decimal(default_credits_raw)
+            if default_credits_raw
+            else None,
         )
         self.org_clusters.append(new_org_cluster)
         return aiohttp.web.json_response(
@@ -596,6 +665,7 @@ class AdminServer:
         org_name = request.match_info["oname"]
         payload = await request.json()
         credits_raw = payload.get("balance", {}).get("credits")
+        default_credits_raw = payload.get("default_credits")
         spend_credits_raw = payload.get("balance", {}).get("spend_credits_raw")
         new_org_cluster = OrgCluster(
             cluster_name=cluster_name,
@@ -609,6 +679,14 @@ class AdminServer:
                 if spend_credits_raw
                 else Decimal(0),
             ),
+            default_quota=Quota(
+                total_running_jobs=payload.get("default_quota", {}).get(
+                    "total_running_jobs"
+                )
+            ),
+            default_credits=Decimal(default_credits_raw)
+            if default_credits_raw
+            else None,
         )
         assert new_org_cluster.org_name == org_name
         self.org_clusters = [
@@ -780,6 +858,10 @@ async def mock_admin_server(
                     "/api/v1/clusters/{cname}",
                     admin_server.handle_cluster_get,
                 ),
+                aiohttp.web.put(
+                    "/api/v1/clusters/{cname}",
+                    admin_server.handle_cluster_put,
+                ),
                 aiohttp.web.delete(
                     "/api/v1/clusters/{cname}",
                     admin_server.handle_cluster_delete,
@@ -940,7 +1022,7 @@ class ApiRunner:
 
         self._api_address_future: asyncio.Future[ApiAddress] = asyncio.Future()
         self._cleanup_future: asyncio.Future[None] = asyncio.Future()
-        self._task: Optional[asyncio.Task[None]] = None
+        self._task: asyncio.Task[None] | None = None
 
     async def _run(self) -> None:
         async with create_local_app_server(self._app, port=self._port) as api_address:
